<?php

/**
 * @file
 * Ubercart Catalog module main filters.
 *
 * Provides main filters generates by advanced_catalog
 *
 */

/**
 * Implements hook_catalog_filters
 *
 * The uc_advanced catalog module comes with a filter manager found at Administer 
 * Store administration  Settings  Catalog settings  Advanced catalog settings
 * that provides filters settings. Filters are generate by hook_catalog_filters
 * Developers that need to create more filters can do so by using this hook.
 *
 * @param $defaults
 *   Array of defaults or current user settings as $key => $value.
 *     Key is filter name and $value the default current value.
 * @param $variables
 *   Provide some variables from the views generated by the module
 *   - 'count': Result count of the view, 0 if empty
 *   - 'total': The total number of results generate by the view for the current page
 * @return
 *   Return an array of filters definition
 *   Each filter is an array with this definition
 *   - 'name': (Required) Internal machine name
 *   - 'edit': (Required) Array of element being used on edit form
 *     -- '#title': (Required) Human name on edit filters form
 *     -- '#summary callback': (Optional)
 *     -- '#summary arguments': (Optional)
 *     -- '#description': (Optional)
 *     -- 'default': (Optional) Default cols
 *       --- '#type': type of element, textfield, select or markup
 *           Depending of type, values of element as From API described
 *           http://api.drupal.org/node/14722
 *     -- 'options': (Optional) Options cols
 *       --- '#multiple': set True if return array of options, default FALSE
 *           if multiple, array of options where key is the name of each option
 *            'options' => array(
 *              '#multiple' => TRUE,
 *                'option1' => array(
 *                  // element options with #type
 *                ),
 *                'option2' => array(
 *                  // element options with #type
 *                ),
 *             ),
 *          else a simple array
 *            'options' => array(
 *              '#multiple' => FALSE, // optional
 *              '#type' => 'textfield',
 *              // any othe fields depending on type
 *             ),
 *        --- '#type': type of element, textfield, select, markup or checkbox
 *        --- Depending of type, values of element as From API described
 *   - 'view': (Required) Element being used on display filters
 *       --- '#type': type of element, textfield, select or markup
 *   - '#weight': (Optional) Default element weight
 */
function uc_advanced_catalog_catalog_filters($defaults = array(), $variables = array()) {

  $images_path = drupal_get_path('module', 'uc_advanced_catalog') .'/images/';
  // extra information filter
  $variables['total'] ? $total = $variables['total']: $total = 0;
  $start = $_REQUEST['page'] * $defaults['limit'] + 1;
  $variables['count'] ? $end = $variables['count']: $end = 0;
  if ($end > $total) {
    $end = $total;
  }
  $value = t('Items !start to !end of !total total', array('!start' => $start, '!end' => $end, '!total' => $total));
  $fields[] = array(
    'name' => 'extra',
    'edit' => array(
      '#title' => t('Extra'),
      '#summary callback' => 'summarize_checkbox',
      '#summary arguments' => array(
        t('Extra pager text is shown.'),
        t('Extra pager text is hidding.'),
      ),
      'options' => array(
        '#value' => t('Display: Items !start to !end of !total total'),
      ),
    ),
    'view' => array(
      '#type' => 'markup',
      '#value' => $value,
    ),
    '#weight' => 1,
  );

  // limit pager filter
  $options = explode(',', variable_get('uc_advanced_catalog_limit_options', '12,20,28,'. t('all')));
  $fields[] = array(
    'name' => 'limit',
    'edit' => array(
      '#title' => t('Limit'),
      '#summary callback' => 'summarize_checkbox',
      '#summary arguments' => array(
        t('Limit filter is visible'),
        t('Limit filter is hidden'),
      ),
      'default' => array(
        '#type' => 'textfield',
        '#size' => 3,
        '#default_value' => variable_get('uc_product_nodes_per_page', 12),
      ),
      'options' => array(
        '#type' => 'textfield',
        '#description' => t('Specify limit option values available. Separate each with comma. Notice that if you are using grid display all values must be multiple of the grid width value, otherwise the last row will not match. "all" can be used to display all values. It make more sense to have default value in the options list.'),
        '#default_value' => '12,20,28,'. t('all'),
        '#size' => 30,
      ),
    ),
    'view' => array(
      '#type' => 'select',
      '#prefix' => t('Show'),
      '#suffix' => t('per page'),
      '#options' => $options,
    ),
    '#weight' => 2,
  );

  // display mode filter
  $view_url = 'admin/build/views/edit/advanced_catalog';
  $show_mode = FALSE;
  $view_as = t('View as') .' ';
  $mode = $defaults['mode'];
  if (variable_get('uc_advanced_catalog_mode_option_grid', TRUE)) {
    $show_mode = TRUE;
    if ($mode == 'block_1') {
      $view_as .= '&nbsp;<strong>'. t('Grid') .'</strong>&nbsp;';
    }
    else {
      $view_as .= '&nbsp;'. l(t('Grid'), $_GET['q'], array('html' => TRUE, 'query' => array('mode' => 'block_1'))) .'&nbsp;';
    }
  }
  if (variable_get('uc_advanced_catalog_mode_option_table', TRUE)) {
    $show_mode = TRUE;
    $mode == 'block_2' ? $view_as .= '&nbsp;<strong>'. t('Table') .'</strong>&nbsp;':
      $view_as .= '&nbsp;'. l(t('Table'), $_GET['q'], array('html' => TRUE, 'query' => array('mode' => 'block_2'))) .'&nbsp;';
  }
  if (variable_get('uc_advanced_catalog_mode_option_list', TRUE)) {
    $show_mode = TRUE;
    $mode == 'block_3' ? $view_as .= '&nbsp;<strong>'. t('List') .'</strong>&nbsp;':
      $view_as .= '&nbsp;'. l(t('List'), $_GET['q'], array('html' => TRUE, 'query' => array('mode' => 'block_3'))) .'&nbsp;';
  }
  $fields[] = array(
    'name' => 'mode',
    'edit' => array(
      '#title' => t('View as'),
      '#summary callback' => 'summarize_checkbox',
      '#summary arguments' => array(
        t('View filter is visible'),
        t('View filter is hidden'),
      ),
      'default' => array(
        '#type' => 'select',
        '#options' => array(
          'block_1' => t('Grid view'),
          'block_2' => t('Table view'),
          'block_3' => t('List view'),
        ),
        '#default_value' => 'block_1',
      ),
      'options' => array(
        '#multiple' => TRUE,
        'grid' => array(
          '#type' => 'checkbox',
          '#title' => t('Grid view') .'&nbsp;'. t('<a href="!url">You can edit this view here.</a>', array('!url' => url($view_url, array('fragment' => 'views-tab-block_1')))),
          '#default_value' => TRUE,
          '#summary callback' => 'summarize_checkbox',
          '#summary arguments' => array(
            t('Grid view enabled.'),
            ''
          ),
        ),
        'table' => array(
          '#type' => 'checkbox',
          '#title' => t('Table view') .'&nbsp;'. t('<a href="!url">You can edit this view here.</a>', array('!url' => url($view_url, array('fragment' => 'views-tab-block_2')))),
          '#default_value' => TRUE,
          '#summary callback' => 'summarize_checkbox',
          '#summary arguments' => array(
            t('Table view enabled.'),
            ''
          ),
        ),
        'list' => array(
          '#type' => 'checkbox',
          '#title' => t('List view') .'&nbsp;'. t('<a href="!url">You can edit this view here.</a>', array('!url' => url($view_url, array('fragment' => 'views-tab-block_3')))),
          '#default_value' => TRUE,
          '#summary callback' => 'summarize_checkbox',
          '#summary arguments' => array(
            t('List view enabled.'),
            ''
          ),
        ),
      ),
    ),
    'view' => array(
      '#type' => 'markup',
      '#value' => $view_as,
    ),
    '#weight' => 3,
  );

  // ordering filter (order)
  $defaults['order'] ? $order = $defaults['order']: $order = 'ordering';
  $options = array();
  if (variable_get('uc_advanced_catalog_order_option_position', TRUE)) {
    $options['ordering'] = t('Position');
  }
  if (variable_get('uc_advanced_catalog_order_option_name', TRUE)) {
    $options['name'] = t('Name');
  }
  if (variable_get('uc_advanced_catalog_order_option_price', TRUE)) {
    $options['price'] = t('Price');
  }
  if (count($options) > 1) {
    $order_view = array(
      '#type' => 'select',
      '#prefix' => t('Sort by') .' ',
      '#options' => $options,
    );
  }
  else {
    $order_view = array(
      '#type' => 'markup',
      '#value' => t('Sort by') .' '. t(drupal_strtolower($options[$order])),
    );
  }
  $fields[] = array(
    'name' => 'order',
    'edit' => array(
      '#title' => t('Ordering'),
      'default' => array(
        '#type' => 'select',
        '#options' => array(
          'ordering' => t('Position'),
          'name' => t('Name'),
          'price' => t('Price'),
        ),
        '#default_value' => $order,
      ),
      'options' => array(
        '#multiple' => TRUE,
        'position' => array(
          '#type' => 'checkbox',
          '#title' => t('Position'),
          '#default_value' => TRUE,
        ),
        'name' => array(
          '#type' => 'checkbox',
          '#title' => t('Name'),
          '#default_value' => TRUE,
        ),
        'price' => array(
          '#type' => 'checkbox',
          '#title' => t('Price'),
          '#default_value' => TRUE,
        ),
      ),
    ),
    'view' => $order_view,
    '#weight' => 4,
  );

  // sort type filter (asc, desc)
  $defaults['sort'] ? $sort = $defaults['sort'] : $sort = 'DESC'; // is this really needed ?
  $options = array(
    'ASC' => t('Ascending'),
    'DESC' => t('Descending'),
  );
  $display = variable_get('uc_advanced_catalog_sort_options', 'image');
  if ($display == 'image') {
    switch ($sort) {
      case 'ASC':
        $img = $images_path .'arrow-desc.png';
        $alt = 'descending';
        $sort = 'DESC';
        break;
      DEFAULT:
        $img = $images_path .'arrow-asc.png';
        $alt = 'ascending';
        $sort = 'ASC';
    }
    $icon_img = theme('image', $img, $alt, t('Click to sort !sort', array('!sort' => $alt)));
    $sort_view = array(
      '#type' => 'markup',
      '#value' => l($icon_img, $_GET['q'], array('html' => TRUE, 'query' => array('sort' => $sort))),
    );
  }
  else {
    $sort_view = array(
      '#type' => 'select',
      '#options' => $options,
    );
  }
  $fields[] = array(
    'name' => 'sort',
    'edit' => array(
      '#title' => t('Sort'),
      'default' => array(
        '#type' => 'select',
        '#options' => $options,
        '#default_value' => 'DESC',
      ),
      'options' => array(
        '#type' => 'select',
        '#options' => array('image' => t('Display as image'), 'select' => t('Display as select')),
        '#description' => t('Specify filter apparence, use image or select field.'),
        '#default_value' => 'image',
      ),
    ),
    'view' => $sort_view,
    '#weight' => 5,
  );
  return $fields;
}
